;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 2A_20x_2
;                     Lampeggia un LED collegato a GP2 alla
;                     cadenza di 1/2 secondo.

;    PIC           :  10F200/2
;    Supporto      :  MPASM
;    Versione      :  1.0
;    Data          :  01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;
;  Impiego pin :
;  ----------------
;     10F200/202 @ 8 pin DIP       10F200/202 @ 6 pin SOT-23
;
;               |\/|                  *|
;           NC -|1    8|- GP3        GP0 -|1    6|- GP3
;          Vdd -|2    7|- Vss        Vss -|2    5|- Vdd
;          GP2 -|3    6|- NC         GP1 -|3    4|- GP2
;          GP1 -|4    5|- GP0             |______|
;               |______|
;
;                       DIP  SOT
;    NC                  1:     nc
;    Vdd                 2:  5: ++
;    GP2/T0CKI/FOSC4     3:  4: Out LED alla Vss
;    GP1/ICSPCLK         4:  3:
;    GP0/ICSPDAT         5:  1:
;    NC                  6:     nc
;    Vss                 7:  2: --
;    GP3/MCLR/VPP        8:  6:
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;GPIO map
; |  3  |  2  |  1  |  0  |
; |-----|-----|-----|-----|
; | in  |     |     | LED |
;
#define    LED GPIO,GP0   ; LED tra pin e Vss
;#define    GPIO,GP1   ;
;#define    GPIO,GP2   ;
;#define    GPIO,GP3   ; solo input
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################
 #ifdef __10F200
        LIST      p=10F200     ; definizione del processore
        #include <p10F200.inc>
 #endif
 #ifdef __10F202
        LIST      p=10F202     ; definizione del processore
        #include <p10F202.inc>
 #endif

        radix     dec          ; default numeri decimali

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; No WDT, no CP, pin4=GP3
;
  __config  _CP_OFF & _MCLRE_OFF  & _WDT_OFF

;########################################RAMONFIGURAZIONE
     CBLOCK  0x10
     d1,d2,d3,d4          ; contatori per ritardi
     ENDC

;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
LED_ON    MACRO
        bsf     LED
          ENDM
LED_OFF   MACRO
        bcf     LED
          ENDM


 PAGE
;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; Reset Vector
RESET_VECTOR   ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni al reset
; OPTION default  11111111
;                 1-------     done
;                 -1------     done
;                 --0-----     disabilita T0CKI
;                 ---1----     done
;                 ----1---     done
;                 -----111     done
        movlw   b'11010111'     ; maschera Option
        option                  ; al registro OPTION

        clrf    GPIO            ; preset GPIO latch a 0

; TRISGPIO        --111110     GP0 out
        movlw   b'11111110'
        tris    GPIO            ; al registro direzione

        goto    mainloop

; tabella salti alle subroutines
Delay05s  goto    Dly05s

===================================================================
mainloop:            ;<<--<<<--|
; accende LED        ;         |
  LED_ON             ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; spegne LED                  loop
  LED_OFF            ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; loop               ;         |
  goto    mainloop   ;>>-->>---|

;===================================================================
;=                      SUBROUTINES                                =
;===================================================================
; Delay = 1/2 secondo @ Clock = 4 MHz
; Fosc/4 = 1 us , 1/2 secondo = 500000 cicli
Dly05s:                  ; 499994 cicli
        movlw   0x03     ; inizializza counter
        movwf   d1       ;
        movlw   0x18     ;
        movwf   d2       ;
        movlw   0x02     ;
        movwf   d3       ;
Dly05s_0:                ; loop di conteggio
        decfsz  d1, f    ; d1=d1-1
        goto    $+2      ;
        decfsz  d2, f    ; d2=d2-2
        goto    $+2      ;
        decfsz  d3, f    ; d3=d3-1
        goto    Dly05s_0 ;
; fine 499994 cicli - ora somma i 6 mancanti
        goto    $+1      ; 2 cicli
        retlw   0        ; 4 cicli compresa call

;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
        END