;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 2As_5089_1
;                     Lampeggia un LED collegato a GP5 alla
;                     cadenza di 1/2 secondo.
;
;    PIC           : 12F508/9
;    Supporto      : MPASM
;    Versione      : 1.0
;    Data          : 01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;--------------------------------------------------------------------
;
;  Impiego pin :
;  ----------------
;       12F508/9 @ 8 pin
;
;                  |\/|
;             Vdd -|1    8|- Vss
;             GP5 -|2    7|- GP0
;             GP4 -|3    6|- GP1
;        GP3/MCLR -|4    5|- GP2
;                  |______|
;
;    Vdd                1: ++
;    GP5/OSC1/CLKIN     2: Out  LED alla Vss
;    GP4/OSC2           3:
;    GP3/!MCLR/VPP      4:
;    GP2/T0CKI          5:
;    GP1/ICSPCLK        6:
;    GP0/ICSPDAT        7:
;    Vss                8: --
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;
;GPIO map
;|  5  |  4  |  3  |  2  |  1  |  0  |
;|-----|-----|-----|-----|-----|-----|
;| LED |     | in  |     |     |     |
;
;#define    GPIO,GP0    ;
;#define    GPIO,GP1    ;
;#define    GPIO,GP2    ;
;#define    GPIO,GP3    ; solo input
;#define    GPIO,P4     ;
#define     LED GPIO,GP5    ; LED tra pin e Vss
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################
;####################################################################
 #ifdef  __12F509
        LIST      p=12F509         ; Definizione del processore
        #include <p12F509.inc>
 #endif
 #ifdef  __12F508
       LIST      p=12F508          ; Definizione del processore
        #include <p12F508.inc>
 #endif

        radix     dec

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
 Oscillatore interno, no WDT, no CP, pin4=GP3
;
 __config  _IntRC_OSC & _WDT_OFF & _CP_OFF & _MCLRE_ON


;####################################################################
;====================================================================
;=                        MEMORIA RAM                               =
;====================================================================
; general purpose RAM
        CBLOCK 0x07         ; inizio area RAM
      d1,d2,d3              ; contatori per ritardo
        ENDC


;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
LED_ON    MACRO
        bsf     LED
          ENDM
LED_OFF   MACRO
        bcf     LED
          ENDM


 PAGE

;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; Reset Vector
        ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni al reset
     clrf   GPIO        ; preset GPIO latch a 0

; TRISGPIO     --011111 GP5 out
     movlw   b'11011111'
     tris    GPIO        ; al registro direzione

     goto    mainloop

; tabella salti alle subroutines
Delay05s  goto    Dly05s

===================================================================
mainloop:            ;<<--<<<--|
; accende LED        ;         |
  LED_ON             ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; spegne LED                  loop
  LED_OFF            ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; loop               ;         |
  goto    mainloop   ;>>-->>---|

;===================================================================
;=                      SUBROUTINES                                =
;===================================================================
; Delay = 1/2 secondo @ Clock = 4 MHz
; Fosc/4 = 1 us , 1/2 secondo = 500000 cicli
Dly05s:                  ; 499994 cicli
        movlw   0x03     ; inizializza counter
        movwf   d1       ;
        movlw   0x18     ;
        movwf   d2       ;
        movlw   0x02     ;
        movwf   d3       ;
Dly05s_0:                ; loop di conteggio
        decfsz  d1, f    ; d1=d1-1
        goto    $+2      ;
        decfsz  d2, f    ; d2=d2-2
        goto    $+2      ;
        decfsz  d3, f    ; d3=d3-1
        goto    Dly05s_0 ;
; fine 499994 cicli - ora somma i 6 mancanti
        goto    $+1      ; 2 cicli
        retlw   0        ; 4 cicli compresa call

;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
        END