;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 2As_519_1
;                     Lampeggia un LED collegato a GP5 alla
;                     cadenza di 1/2 secondo.
;
;    PIC           : 12F519
;    Supporto      : MPASM
;    Versione      : 1.0
;    Data          : 01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;--------------------------------------------------------------------
;
;  Impiego pin :
;  ----------------
;       12F519 @ 8 pin
;
;                  |\/|
;             Vdd -|1    8|- Vss
;             GP5 -|2    7|- GP0
;             GP4 -|3    6|- GP1
;        GP3/MCLR -|4    5|- GP2
;                  |______|
;
;    Vdd                1: ++
;    GP5/OSC1/CLKIN     2: Out  LED alla Vss
;    GP4/OSC2           3:
;    GP3/!MCLR/VPP      4:
;    GP2/T0CKI          5:
;    GP1/ICSPCLK        6:
;    GP0/ICSPDAT        7:
;    Vss                8: --
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;
;GPIO map
;|  5  |  4  |  3  |  2  |  1  |  0  |
;|-----|-----|-----|-----|-----|-----|
;| LED |     | in  |     |     |     |
;
;#define    GPIO,GP0    ;
;#define    GPIO,GP1    ;
;#define    GPIO,GP2    ;
;#define    GPIO,GP3    ; solo input
;#define    GPIO,P4     ;
#define     LED GPIO,GP5    ; LED tra pin e Vss
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################

        LIST      p=12F519         ; Definizione del processore
        #include <p12F519.inc>

        radix     dec

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; Oscillatore interno, no WDT, no CP, pin4=MCLR
;
 __config  _IntRC_OSC & _IOSCFS_4MHz & _WDTE_OFF & _CP_OFF & _CPDF_OFF & _MCLRE_ON


;####################################################################
;====================================================================
;=                        MEMORIA RAM                               =
;====================================================================
; general purpose RAM
        CBLOCK 0x07         ; inizio area RAM
      d1,d2,d3              ; contatori per ritardo
        ENDC


;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
LED_ON    MACRO
        bsf     LED
          ENDM
LED_OFF   MACRO
        bcf     LED
          ENDM


 PAGE

;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; Reset Vector
        ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni al reset
     clrf   GPIO        ; preset GPIO latch a 0

; TRISGPIO     --011111 GP5 out
 movlw   b'11011111'
     tris    GPIO        ; al registro direzione

 goto    mainloop

; tabella salti alle subroutines
Delay05s  goto    Dly05s

===================================================================
mainloop:            ;<<--<<<--|
; accende LED        ;         |
  LED_ON           ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; spegne LED                  loop
  LED_OFF           ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; loop               ;         |
  goto mainloop   ;>>-->>---|

;===================================================================
;=                      SUBROUTINES                                =
;===================================================================
; Delay = 1/2 secondo @ Clock = 4 MHz
; Fosc/4 = 1 us , 1/2 secondo = 500000 cicli
Dly05s:       ; 499994 cicli
        movlw   0x03     ; inizializza counter
        movwf   d1       ;
        movlw   0x18     ;
        movwf   d2       ;
        movlw   0x02     ;
        movwf   d3       ;
Dly05s_0:                ; loop di conteggio
        decfsz  d1, f    ; d1=d1-1
        goto    $+2      ;
        decfsz  d2, f    ; d2=d2-2
        goto    $+2      ;
        decfsz  d3, f    ; d3=d3-1
        goto    Dly05s_0 ;
; fine 499994 cicli - ora somma i 6 mancanti
        goto    $+1      ; 2 cicli
        retlw   0        ; 4 cicli compresa call

;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
        END

 PAGE
;********************************************************************
; ===================================================================
; =                       DOCUMENTAZIONE                            =
;====================================================================
;********************************************************************
; Opzioni CONFIG
;********************************************************************
;
; Oscillatore
; ---------------------------------------------
;_FOSC_LP         ; osc. esterno LP con 18ms DRT
;_LP_OSC          ; alias
;_FOSC_XT         ; osc. esterno XP con 18ms DRT
;_XT_OSC          ; alias
;_FOSC_INTRC      ; osc. interno con 1.125ms DRT
;_IntRC_OSC       ; alias
;_FOSC_EXTRC      ; osc. esterno RC con 1.125ms DRT
;_ExtRC_OSC       ; alias

;  Frequenza oscillatore interno
; ---------------------------------------------
;_IOSCFS_4MHz     ; 4 MHz INTOSC
;_IOSCFS_8MHz     ; 8 MHz INTOSC

; Watchdog
; ---------------------------------------------
;_WDTE_ON         ; abilitato
;_WDTE_OFF        ; disabilitato

; Protezione della memoria programma
; ---------------------------------------------
;_CP_ON           ; protezione abilitata
;_CP_OFF          ; protezione disabilitata

; Pin MCLR
; ---------------------------------------------
;_MCLRE_ON        ; GP3/MCLR come MCLR
;_MCLRE_OFF       ; GP3/MCLR come GP3

; Protezione della EEPROM
; ---------------------------------------------
;_CPDF_ON         ; protezione abilitata
;_CPDF_OFF        ; protezione disabilitata


;********************************************************************
;                        PRINCIPALI SFR                             *
;********************************************************************
; SFR su due banchi
; STATUS, INDF, PCL, FSR accessibili da entrambi i banchi
; GPIO, OSCCAL, TMR0     accessibili solo dal Bank0
; EECON, EEDATA, EEADR   accessibili solo dal Bank1

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 0
;
;OPTION_REG - Options & TIMER0 - scrivibile con option
;------------------------------------------------------
; al POR          '11111111'
OPTIONVAL   EQU  B'11010111'
         ;          1-------     GPWU disabilitato
         ;          -1------     GPPU disabilitato
         ;          --0-----     clock interno
         ;          ---1----     falling
         ;          ----0---     prescaler al timer
         ;          -----111     1:256
 ;
         ; NOT_GPWU  b7 : enable wake-up pin on change
         ;                1= disabilitato
         ;                0= abilitato
         ; NOT_GPPU  b6 : Enable Weak Pull-ups bit
         ;                1= disabilitato
         ;                0= abilitato
         ; TOCS      b5 : 1= clock TMR0 esterno da GP2
         ;                0= clock interno
         ; TOSE      b4 : 1= GP2 fronte discendente (b5=1)
         ;                0= GP2 fronte in salita   (b5=1)
         ; PSA       b3 : 1= predivisore al Watchdog
         ;                0= predivisore a TMR0
         ; PS2/PS0   b2/b0 valore del predivisore
         ;                  Watchdog   Timer0
         ;           000 =  1/1        1/2
         ;           001 =  1/2        1/4
         ;           010 =  1/4        1/8
         ;           011 =  1/8        1/16
         ;           100 =  1/16       1/32
         ;           101 =  1/32       1/64
         ;           110 =  1/64       1/128
         ;           111 =  1/128      1/256


; OSCCAL - Calibrazione oscillatore interno - bank 0
; ---------------------------------------------------
OSCCALDEF  EQU    B'00000000' ; valore intermedio
        ; CAL6:0    b7:1  : 01111 = Maximum frequency
        ;                   00000 = Center frequency
        ;                   10000 = Minimum frequency
        ; riservato b0


; Ordine di precedenza delle funzioni dei PORT
; # | GP0  | GP1  | GP2  |  GP3 | GP4  | GP5  |
;-----------------|------|------|-------------|
; 1 | TRIS | TRIS | T0CKI|I/MCLR| TRIS | TRIS |
; 3 |   -  |   -  | TRIS |  -   |   -  |   -  |


; GPIO - Registro GPIO
; ---------------------
; al POR          '----xxxx'

; TRISGPIO - Direzione GPIO
; --------------------------
; al POR          '--111111'
DIRPORT    EQU   B'--011111'
         ;         ||||||||____ TRISGP0 in
         ;         |||||||_____ TRISGP1 in
         ;         ||||||______ TRISGP2 in
         ;         |||||_______ TRISGP3 solo in
         ;         ||||________ TRISGP4 in
         ;         |||_________ TRISGP5 out
         ;         ||__________ non usati

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 1
;
;EECON - Controllo EEPROM - bank 1
;----------------------------------
        ; reserved b7:5-------: reserved
        ; FREE     b4 --------: forza cancellazione
        ; WRERR    b3 --------: errore reset
        ; WREN     b2 --------: abilita scrittura
        ; WR       b1 --------: scrittura
        ; RD       b0 --------: lettura


; EEDATA - Registro dati EEPROM - bank 1
; ---------------------------------------

; EEADR - Registro indirizzo EEPROM - bank 1
; -------------------------------------------