;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 2As_519_2
;                     Lampeggia un LED collegato a GP2 alla
;                     cadenza di 1/2 secondo.
;
;    PIC           : 12F519
;    Supporto      : MPASM
;    Versione      : 1.0
;    Data          : 01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;--------------------------------------------------------------------
;
;  Impiego pin :
;  ----------------
;       12F519 @ 8 pin
;
;                  |\/|
;             Vdd -|1    8|- Vss
;             GP5 -|2    7|- GP0
;             GP4 -|3    6|- GP1
;        GP3/MCLR -|4    5|- GP2
;                  |______|
;
;    Vdd                1: ++
;    GP5/OSC1/CLKIN     2:
;    GP4/OSC2           3:
;    GP3/!MCLR/VPP      4:
;    GP2/T0CKI          5: Out  LED alla Vss
;    GP1/ICSPCLK        6:
;    GP0/ICSPDAT        7:
;    Vss                8: --
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;
;GPIO map
;|  5  |  4  |  3  |  2  |  1  |  0  |
;|-----|-----|-----|-----|-----|-----|
;|     |     | in  | LED |     |     |
;
;#define    GPIO,GP0    ;
;#define    GPIO,GP1    ;
#define    LED GPIO,GP2    ; LED tra pin e Vss
;#define    GPIO,GP3    ; solo input
;#define    GPIO,P4     ;
;#define    GPIO,GP5    ;
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################

        LIST      p=12F519         ; Definizione del processore
        #include <p12F519.inc>

        radix     dec

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; Oscillatore interno, no WDT, no CP, pin4=MCLR
;
 __config  _IntRC_OSC & _IOSCFS_4MHz & _WDTE_OFF & _CP_OFF & _CPDF_OFF & _MCLRE_ON


;####################################################################
;====================================================================
;=                        MEMORIA RAM                               =
;====================================================================
; general purpose RAM
        CBLOCK 0x07         ; inizio area RAM
      d1,d2,d3              ; contatori per ritardo
        ENDC


;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
LED_ON    MACRO
        bsf     LED
          ENDM
LED_OFF   MACRO
        bcf     LED
          ENDM


 PAGE

;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; Reset Vector
        ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:; inizializzazioni al reset
; OPTION default  11111111
;                 1-------     done
;                 -1------     done
;                 --0-----     disabilita T0CKI
;                 ---1----     done
;                 ----1---     done
;                 -----111     done
        movlw   b'11010111'
        option                  ; al registro OPTION

        clrf   GPIO            ; preset GPIO latch a 0

; TRISGPIO        --011111 GP5 out
    movlw   b'11011111'     ; maschera direzione PORT
        tris    GPIO            ; al registro direzione

        goto    mainloop

; tabella salti alle subroutines
Delay05s  goto    Dly05s

===================================================================
mainloop:            ;<<--<<<--|
; accende LED        ;         |
  LED_ON             ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; spegne LED                  loop
  LED_OFF            ;         |
                     ;         |
; attesa 1s                    |
  call    Delay05s   ;         |
                     ;         |
; loop               ;         |
  goto    mainloop   ;>>-->>---|

;===================================================================
;=                      SUBROUTINES                                =
;===================================================================
; Delay = 1/2 secondo @ Clock = 4 MHz
; Fosc/4 = 1 us , 1/2 secondo = 500000 cicli
Dly05s:                  ; 499994 cicli
        movlw   0x03     ; inizializza counter
        movwf   d1       ;
        movlw   0x18     ;
        movwf   d2       ;
        movlw   0x02     ;
        movwf   d3       ;
Dly05s_0:                ; loop di conteggio
        decfsz  d1, f    ; d1=d1-1
        goto    $+2      ;
        decfsz  d2, f    ; d2=d2-2
        goto    $+2      ;
        decfsz  d3, f    ; d3=d3-1
        goto    Dly05s_0 ;
; fine 499994 cicli - ora somma i 6 mancanti
        goto    $+1      ; 2 cicli
        retlw   0        ; 4 cicli compresa call

;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
        END