;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 1As_20x
;                     Lampeggia un LED collegato a GP0 alla
;                     cadenza di 1 secondo.

;    PIC           :  10F200/2
;    Supporto      :  MPASM
;    Versione      :  1.0
;    Data          :  01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;
;  Impiego pin :
;  ----------------
;     10F200/202 @ 8 pin DIP       10F200/202 @ 6 pin SOT-23
;
;               |\/|                  *|
;           NC -|1    8|- GP3        GP0 -|1    6|- GP3
;          Vdd -|2    7|- Vss        Vss -|2    5|- Vdd
;          GP2 -|3    6|- NC         GP1 -|3    4|- GP2
;          GP1 -|4    5|- GP0             |______|
;               |______|
;
;                       DIP  SOT
;    NC                  1:     nc
;    Vdd                 2:  5: ++
;    GP2/T0CKI/FOSC4     3:  4:
;    GP1/ICSPCLK         4:  3:
;    GP0/ICSPDAT         5:  1: Out LED alla Vss
;    NC                  6:     nc
;    Vss                 7:  2: --
;    GP3/MCLR/VPP        8:  6:
;
;********************************************************************
;            DEFINIZIONE DI IMPIEGO DEI PORT
;GPIO map
; |  3  |  2  |  1  |  0  |
; |-----|-----|-----|-----|
; | in  |     |     | LED |
;
#define    LED GPIO,GP0   ; LED tra pin e Vss
;#define    GPIO,GP1   ;
;#define    GPIO,GP2   ;
;#define    GPIO,GP3   ; solo input
;
;####################################################################
 #ifdef __10F200
        LIST      p=10F200     ; definizione del processore
        #include <p10F200.inc>
 #endif
 #ifdef __10F202
        LIST      p=10F202     ; definizione del processore
        #include <p10F202.inc>
 #endif

        radix     dec          ; default numeri decimali

;####################################################################
;                          CONFIGURAZIONE
;
; No WDT, no CP, pin4=GP3;
  __config  _CP_OFF & _MCLRE_OFF  & _WDT_OFF

;####################################################################
;                          RAM
     CBLOCK  0x10
     d1,d2,d3,d4          ; contatori per ritardi
     ENDC

;####################################################################
;                          LOCAL MACROS
;
; Comandi per il LED
LED_ON    MACRO
        bsf     LED
          ENDM
LED_OFF   MACRO
        bcf     LED
          ENDM

;####################################################################
;                           RESET ENTRY
;
; Reset Vector
RESET_VECTOR   ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL

;####################################################################
;                        MAIN PROGRAM
;
MAIN:
; inizializzazioni al reset
        clrf    GPIO            ; preset GPIO latch a 0

; TRISGPIO        --111110     GP0 out
        movlw   b'11111110'
        tris    GPIO            ; al registro direzione

        goto    mainloop

; tabella salti alle subroutines
Delay1s  goto    Dly1s

;===================================================================
mainloop:            ;<<--<<<--|
; accende LED        ;         |
  LED_ON             ;         |
                     ;         |
; attesa 1s                    |
  call    Delay1s    ;         |
                     ;         |
; spegne LED                  loop
  LED_OFF            ;         |
                     ;         |
; attesa 1s                    |
  call    Delay1s    ;         |
                     ;         |
; loop               ;         |
  goto    mainloop   ;>>-->>---|

;===================================================================
;=                      SUBROUTINES                                =
;===================================================================
; Delay = 1 secondo @ Clock = 4 MHz
; Fosc/4 = 1 us , 1 secondo = 1000000 cicli
Dly1s:                   ; 999990 cicli
        movlw   0x07     ; inizializza counter
        movwf   d1       ;
        movlw   0x2F     ;
        movwf   d2       ;
        movlw   0x03     ;
        movwf   d3       ;
Dly1s_0:                 ; loop di conteggio
        decfsz  d1, f    ; d1=d1-1
        goto    $+2      ;
        decfsz  d2, f    ; d2=d2-2
        goto    $+2      ;
        decfsz  d3, f    ; d3=d3-1
        goto    Dly1s_0  ;
; fine 999990 cicli - ora somma i 10 mancanti
        goto    $+1      ; 6 cicli
        goto    $+1      ;
        goto    $+1      ;
        retlw   0        ; 4 cicli compresa call

;********************************************************************
;                            THE END
        END

